|PyPI1| |PyPI2| |PyPI3| |Codecov| |Build Status| |Documentation Status| |Maintenance|

|PyPI4|


Overview
========

Mathmaker Lib offers lualatex-printable mathematical objects.

`Repo is here <https://gitlab.com/nicolas.hainaux/mathmakerlib>`__

`See documentation here <http://mathmaker-lib.readthedocs.io/>`__

Contact: nh dot techn (hosted by gmail dot com)

.. |PyPI1| image:: https://img.shields.io/pypi/v/mathmakerlib.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/mathmakerlib
.. |PyPI2| image:: https://img.shields.io/pypi/status/mathmakerlib.svg?maxAge=2592000
.. |PyPI3| image:: https://img.shields.io/pypi/pyversions/mathmakerlib.svg?maxAge=2592000
.. |Build Status| image:: https://ci.appveyor.com/api/projects/status/7vejgm0hjm6236xo/branch/master?svg=true
   :target: https://ci.appveyor.com/project/nicolashainaux/mathmakerlib-ho94f
.. |Codecov| image:: https://codecov.io/gl/nicolas.hainaux/mathmakerlib/branch/master/graph/badge.svg
  :target: https://codecov.io/gl/nicolas.hainaux/mathmakerlib
.. |Documentation Status| image:: https://readthedocs.org/projects/mathmaker-lib/badge/?version=latest
   :target: https://mathmaker-lib.readthedocs.io/en/latest/
.. |Maintenance| image:: https://img.shields.io/maintenance/yes/2019.svg?maxAge=2592000
.. |PyPI4| image:: https://img.shields.io/pypi/l/mathmakerlib.svg?maxAge=2592000
   :target: https://gitlab.com/nicolas.hainaux/mathmakerlib/blob/master/LICENSE
